#!/usr/bin/env python
# -*- coding: utf-8; mode: python; -*-
#
#  GStreamer Inspector - Multimedia system plugin introspection
#
#  Copyright (C) 2007 René Stadler <mail@renestadler.de>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the Free
#  Software Foundation; either version 3 of the License, or (at your option)
#  any later version.
#
#  This program is distributed in the hope that it will be useful, but WITHOUT
#  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
#  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
#  more details.
#
#  You should have received a copy of the GNU General Public License along with
#  this program.  If not, see <http://www.gnu.org/licenses/>.

"""GStreamer Inspector NameValuePageBase demo."""

import sys
import os
import os.path

sys.path.insert (0, os.path.join (sys.path[0], os.pardir))

from GstInspector import GUI

import gtk

class Widgets (object):

    def __init__ (self):

        self.window = gtk.Window ()
        self.window.set_default_size (400, 500)
        self.window.props.border_width = 12
        self.window.show ()

        self.notebook = gtk.Notebook ()

        self.demo_scrolled = gtk.ScrolledWindow ()
        self.demo_scrolled.set_policy (gtk.POLICY_AUTOMATIC,
                                       gtk.POLICY_AUTOMATIC)

        self.demo_view = gtk.TreeView ()
        self.demo_view.props.headers_visible = False

        self.demo_scrolled.add_with_viewport (self.demo_view)
        self.notebook.append_page (self.demo_scrolled,
                                   gtk.Label ("spanning"))

        self.normal_scrolled = gtk.ScrolledWindow ()
        self.normal_scrolled.set_policy (gtk.POLICY_AUTOMATIC,
                                         gtk.POLICY_AUTOMATIC)

        self.normal_view = gtk.TreeView ()
        self.normal_view.props.headers_visible = False

        self.normal_scrolled.add_with_viewport (self.normal_view)
        self.notebook.append_page (self.normal_scrolled,
                                   gtk.Label ("normal"))
        
        self.window.add (self.notebook)
        self.window.show_all ()

class DemoModel (GUI.NameValueModel):

    def __init__ (self):

        GUI.NameValueModel.__init__ (self)

        def set (i, name, value):
            self.set (i,
                      self.COL_NAME, name,
                      self.COL_VALUE, value)

        i = None
        for x in range (5):
            i = self.append (i)
            set (i, "Test %i" % (x,), "Nested further")

        i = None
        for x in range (5):
            i = self.append (i)
            if x % 2:
                set (i, "Test %i" % (x,), "Name not spanning")
            else:
                set (i, "Test %i spanning" % (x,), None)
        for x in range (3):
            i2 = self.append (i)
            set (i2, "Name", "value " * 12)
    
class DemoPage (GUI.NameValuePageBase):

    name = "demo"
    view_name = "demo_view"
    widget_name = "demo_scrolled"

    def __init__ (self, *a, **kw):

        GUI.NameValuePageBase.__init__ (self, *a, **kw)

        # self.DEBUG_DRAW_COLORED_AREAS = True
        # self.cell.DEBUG_DISABLE_DRAW_SPACING = True

        view = self.view
        view.props.model = DemoModel ()
        view.expand_all ()
        for column in view.get_columns ():
            column.queue_resize ()

rc_style = """

style "demo"
{
  /* GtkWidget::focus-line-width = 4 */

  /* GtkTreeView::expander-size = 32 */
  /* GtkTreeView::horizontal-separator = 48 */
  /* GtkTreeView::vertical-separator = 8 */
}

class "GtkWidget" style "demo"
"""

def main ():

    gtk.rc_parse_string (rc_style)

    widgets = Widgets ()

    page = DemoPage (widgets)

    view = widgets.normal_view
    model = DemoModel ()
    view.props.model = model

    column = gtk.TreeViewColumn ("")
    cell = gtk.CellRendererText ()
    cell.props.cell_background = "blue"
    cell.props.background = "yellow"
    column.pack_start (cell, True)
    column.add_attribute (cell, "text", model.COL_NAME)
    view.append_column (column)
    column = gtk.TreeViewColumn ("")
    cell = gtk.CellRendererText ()
    cell.props.cell_background = "red"
    cell.props.background = "green"
    column.pack_start (cell, True)
    column.add_attribute (cell, "text", model.COL_VALUE)
    view.append_column (column)

    view.expand_all ()

    def window_delete_event (window, event):
        gtk.main_quit ()
    widgets.window.connect ("delete-event", window_delete_event)
    gtk.main ()

if __name__ == "__main__":
    main ()
