#!/usr/bin/env python
# -*- coding: utf-8; mode: python; -*-
#
#  GStreamer Inspector - Multimedia system plugin introspection
#
#  Copyright (C) 2007 René Stadler <mail@renestadler.de>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the Free
#  Software Foundation; either version 3 of the License, or (at your option)
#  any later version.
#
#  This program is distributed in the hope that it will be useful, but WITHOUT
#  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
#  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
#  more details.
#
#  You should have received a copy of the GNU General Public License along with
#  this program.  If not, see <http://www.gnu.org/licenses/>.

"""GStreamer Inspector test suite for the main module."""

import sys
import os
import os.path

sys.path.insert (0, os.path.join (sys.path[0], os.pardir))

from unittest import TestCase, main as test_main

import pygtk
pygtk.require ("2.0")
del pygtk

import gobject
import gtk

from GstInspector import main

class TestError (Exception):

    pass

class TestMainLoopWrapper (TestCase):

    def setUp (self):

        main.ExceptHookManager.setup ()

    def tearDown (self):

        # Restore any global settings to the defaults:
        main.ExceptHookManager.shutdown ()
        # Replace with a fresh instance to ensure all state is cleared:
        main.ExceptHookManager = type (main.ExceptHookManager) ()

    def test_gtk_main (self):

        def quitting_timeout ():
            gtk.main_quit ()
            return False

        gobject.timeout_add (100, quitting_timeout)

        main.MainLoopWrapper (gtk.main, gtk.main_quit).run ()

    def test_gtk_main_exception (self):

        def failing_timeout ():
            raise TestError ("testing exception handling")

        gobject.timeout_add (100, failing_timeout)

        run = main.MainLoopWrapper (gtk.main, gtk.main_quit).run

        self.assertRaises (TestError, run)

if __name__ == "__main__":
    test_main ()
